#!/bin/sh

# This shell script installs NFTP binaries and support files

# Set defaults

TARGETBIN="/usr/local/bin"
TARGETLIB="/usr/local/lib/nftp"
TARGETDOC="/usr/doc/nftp"
TARGETMAN="/usr/man/man1"

# Issue a message for user and wait for decision

clear
echo
echo "NFTP installation. Must be run as super-user."
echo
echo "This script will install the following files:"
echo
echo $TARGETBIN"/nftp              - NFTP executable"
echo $TARGETLIB"/nls/*        - National language support files"
echo $TARGETLIB"/nftp.i       - Global template for initialization file"
echo $TARGETLIB"/keynames     - Keynames executable"
echo $TARGETLIB"/uninstall.sh - script for uninstalling NFTP"
echo $TARGETMAN"/nftp.1             - man page for NFTP"
echo $TARGETDOC"/*                  - documentation"
echo

echo "Press ENTER to continue, or Ctrl-C to cancel"
read x

# Install everything

echo "Making directories..."

mkdir -p -m 755 $TARGETBIN
mkdir -p -m 755 $TARGETLIB/nls
mkdir -p -m 755 $TARGETMAN
mkdir -p -m 755 $TARGETDOC

echo "Now copying files and setting permissions..."

echo "Copying executables..."
cp nftp       $TARGETBIN
chown bin     $TARGETBIN/nftp
chmod 755     $TARGETBIN/nftp

cp keynames   $TARGETLIB
chown bin     $TARGETLIB/keynames
chmod 755     $TARGETLIB/keynames

cp uninstall.sh $TARGETLIB
chown root    $TARGETLIB/uninstall.sh
chmod 755     $TARGETLIB/uninstall.sh

cp nftp.i     $TARGETLIB
chown bin     $TARGETLIB/nftp.i
chmod 755     $TARGETLIB/nftp.i

echo "Copying NLS files..."
cp *.nls *.dos $TARGETLIB/nls
chown bin     $TARGETLIB/nls/*
chmod 755     $TARGETLIB/nls/*

echo "Copying manual page and HTML documentation..."
cp nftp.1     $TARGETMAN
chmod 755     $TARGETMAN/nftp.1

cp *.html     $TARGETDOC
cp readme.*   $TARGETDOC
chmod 755     $TARGETDOC/*.html $TARGETDOC/readme.*

echo "Installation is complete."
